if ($env:chocolateyPackageParameters -eq $null) {
    Write-ChocolateyFailure 'TeamCityAgent' "No parameters have been passed into Chocolatey install, e.g. -params 'serverurl=http://...'"
}

$parameters = ConvertFrom-StringData -StringData $env:chocolateyPackageParameters.Replace(";", "`n")

## Validate parameters
if ($parameters["serverurl"] -eq $null) {
    Write-ChocolateyFailure 'TeamCityAgent' "Please specify the TeamCity server URL by passing it as a parameter to Chocolatey install, e.g. -params 'serverurl=http://...'"
}
if ($parameters["agentdir"] -eq $null) {
    $parameters["agentdir"] = "$env:SystemDrive\buildAgent"
    Write-Host No agent directory is specified. Defaulting to $parameters["agentdir"]
}

## Make local variables of it
$serverUrl = $parameters["serverurl"];
$agentDir = $parameters["agentdir"];

## Download from TeamCity server
Get-ChocolateyWebFile 'buildAgent.zip' "$env:TEMP\buildAgent.zip" "$serverUrl/update/buildAgent.zip"

## Extract
Get-ChocolateyUnzip "$env:TEMP\buildAgent.zip" $agentDir  

## Clean up
del "$env:TEMP\buildAgent.zip"

# Configure agent
copy $agentDir\conf\buildAgent.dist.properties $agentDir\conf\buildAgent.properties
(Get-Content $agentDir\conf\buildAgent.properties) | Foreach-Object {
    $_ -replace 'serverUrl=http://localhost:8111/', "serverUrl=$serverUrl"
    } | Set-Content $agentDir\conf\buildAgent.properties

Start-ChocolateyProcessAsAdmin "/C `"cd $agentDir\bin && $agentDir\bin\service.install.bat && $agentDir\bin\service.start.bat`"" cmd

## Done!
Write-ChocolateySuccess 'TeamCityAgent'
exit